==> resin-4.0.27-src.tar.gz: resin-4.0.27/modules/resin/src/com/caucho/json/ser/CollectionSerializer.java <==
/*
 * Copyright (c) 1998-2012 Caucho Technology -- all rights reserved
 *
 * This file is part of Resin(R) Open Source
 *
 * Each copy or derived work must preserve the copyright notice and this
 * notice unmodified.
 *
 * Resin Open Source is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * Resin Open Source is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE, or any warranty
 * of NON-INFRINGEMENT.  See the GNU General Public License for more
 * details.
 *
 * You should have received a copy of the GNU General Public License
 * along with Resin Open Source; if not, write to the
 *
 *   Free Software Foundation, Inc.
 *   59 Temple Place, Suite 330
 *   Boston, MA 02111-1307  USA
 *
 * @author Scott Ferguson
 */

package com.caucho.json.ser;

import com.caucho.json.JsonOutput;

import java.io.*;
import java.util.*;

public class CollectionSerializer extends AbstractJsonSerializer<Collection> {
  static final JsonSerializer SER = new CollectionSerializer();

  private CollectionSerializer() {}
  
  public void write(JsonOutput out, Collection value, boolean annotated)
    throws IOException
  {
    int i = 0;
    
    out.writeArrayBegin();
    for (Object child : value) {
      if (i != 0)
        out.writeArrayComma();
      i++;
      out.writeObject((Serializable) child, annotated);
    }
    out.writeArrayEnd();
  }
}

==> resin-4.0.65-src.tar.gz: resin-4.0.65/modules/resin/src/com/caucho/json/ser/CollectionSerializer.java <==
/*
 * Copyright (c) 1998-2018 Caucho Technology -- all rights reserved
 *
 * This file is part of Resin(R) Open Source
 *
 * Each copy or derived work must preserve the copyright notice and this
 * notice unmodified.
 *
 * Resin Open Source is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * Resin Open Source is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE, or any warranty
 * of NON-INFRINGEMENT.  See the GNU General Public License for more
 * details.
 *
 * You should have received a copy of the GNU General Public License
 * along with Resin Open Source; if not, write to the
 *
 *   Free Software Foundation, Inc.
 *   59 Temple Place, Suite 330
 *   Boston, MA 02111-1307  USA
 *
 * @author Scott Ferguson
 */

package com.caucho.json.ser;

import com.caucho.json.JsonOutput;

import java.io.*;
import java.util.*;

public class CollectionSerializer extends AbstractJsonSerializer<Collection> {
  static final JsonSerializer SER = new CollectionSerializer();

  private CollectionSerializer() {}
  
  public void write(JsonOutput out, Collection value, boolean annotated)
    throws IOException
  {
    int i = 0;
    
    out.writeArrayBegin();
    for (Object child : value) {
      if (i != 0)
        out.writeArrayComma();
      i++;
      out.writeObject(child, annotated);
    }
    out.writeArrayEnd();
  }
}
